lilypondparsertools.SyntaxNode
==============================

.. inheritance-diagram:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode
   :private-bases:

.. autoclass:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__getitem__

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__len__

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__repr__

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__str__
